package com.supervision.pdfqaserver.dto;

import cn.hutool.core.collection.CollUtil;
import com.supervision.pdfqaserver.dto.neo4j.NodeData;
import com.supervision.pdfqaserver.dto.neo4j.RelationObject;
import com.supervision.pdfqaserver.dto.neo4j.RelationshipData;
import lombok.Data;

@Data
public class AnswerDetailDTO {

    /**
     * 文档片段id
     */
    private String truncateId;

    /**
     * 头节点类型
     */
    private String sourceType;

    /**
     * 头节点名称
     */
    private String sourceName;

    /**
     * 目标节点类型
     */
    private String targetType;


    /**
     * 目标节点名称
     */
    private String targetName;

    /**
     * 关系
     */
    private String relation;

    /**
     * 片段内容
     */
    private String truncateContent;

    /**
     * PDF ID
     */
    private String pdfId;

    /**
     * PDF 名称
     */
    private String pdfName;

    public AnswerDetailDTO() {
    }

    public AnswerDetailDTO(RelationObject relationObject) {
        NodeData endNode = relationObject.endNode();
        NodeData startNode = relationObject.startNode();
        RelationshipData relationship = relationObject.relationship();
        if (null == startNode || null == endNode || null == relationship){
            return;
        }
        if (CollUtil.isNotEmpty(startNode.properties())){
            Object truncationId = startNode.properties().get("truncationId");
            if (null != truncationId){
                this.truncateId = truncationId.toString();
            }
        }
        if (CollUtil.isNotEmpty(endNode.labels())){
            this.sourceType = String.join(",", endNode.labels());
        }
        if (CollUtil.isNotEmpty(startNode.properties())){
            if (null != startNode.properties().get("name")){
                this.sourceName = startNode.properties().get("name").toString();
            }
        }
        if (CollUtil.isNotEmpty(endNode.labels())){
            this.targetType = String.join(",", startNode.labels());
        }
        if (CollUtil.isNotEmpty(endNode.properties())){
            if (null != startNode.properties().get("name")){
                this.targetName = endNode.properties().get("name").toString();
            }
        }
        if (CollUtil.isNotEmpty(relationship.properties())) {
            this.relation = relationship.type();
        }
    }
}
